childLoading property
Customizable child widgets to display based on the different states.
Implementation
final Widget? child, childErro, childLoading, childEmpty, childWaiting;
Customizable child widgets to display based on the different states.
final Widget? child, childErro, childLoading, childEmpty, childWaiting;